pocketpose.models.factory - PocketPose 0.0.1 documentation

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Edit this page
Toggle table of contents sidebar

# `pocketpose.models.factory`

Model factory to create models from their names.

This module contains a factory to create models from their names. The factory is used to create models, which can then be retrieved by name using the model factory.

Example:

      >>> from pocketpose.models.factory import ModelFactory
      >>> model = ModelFactory.create("model1")

## Module Contents

### Classes

`ModelFactory` |

class pocketpose.models.factory.ModelFactory
  classmethod create(model_name, *args, **kwargs)